# A simple Python 3 based relay control example for EasyDAQ DAQPod units
# Sequence the relays on and off then send random numbers to the relays
# The 8 relays are are on Port E
#
# N.J.Halse 24/11/23

import u3       # LabJack U3 library
import time
import random


d = u3.U3()
delay = 0.25

d.debug = True  # sends debug data to terminal

# all port E to low
d.getFeedback(u3.PortStateWrite(State = [0x00, 0x00, 0x00], WriteMask = [0x00, 0xff, 0x00]))

# all port E to output
d.getFeedback(u3.PortDirWrite(Direction = [0x00, 0x00, 0x00], WriteMask = [0x00, 0xff, 0x00]))

time.sleep(1)
for x in range(8,16):   # turn on each relay in sequence
    d.getFeedback(u3.BitStateWrite(IONumber=x, State=1))
    time.sleep(delay)

for x in range(8,16):   # turn off each relay in sequence
    d.getFeedback(u3.BitStateWrite(IONumber=x, State=0))
    time.sleep(delay)

for x in range(0,20):   # output 20 random values
    y=(random.randrange(0, 255))
    d.getFeedback(u3.PortStateWrite(State=[0x00, y, 0x00], WriteMask=[0x00, 0xff, 0x00]))
    time.sleep(delay)
time.sleep(1)

# all port E to low
d.getFeedback(u3.PortStateWrite(State = [0x00, 0x00, 0x00], WriteMask = [0x00, 0xff, 0x00]))
